<?php
/*-----------------------------------------------------
    NewsLister post.php
	
    @package NewsLister
	@since 1.0
	
	@version    1.0.1
	@copyright Tenderfeel
	@author Tenderfeel(tenderfeel@gmail.com)
	@link http://tenderfeel.xsrv.jp/ 
	
	[2010/03/15] 1.0.1
	 * comment_format() 独自wiki記法追加
	 + date3339() Atom用追加
	 * get_lastpostmodified() Atom用スイッチ
	 
------------------------------------------------------*/
require_once("config.php");
require_once("FastJSON.class.php");

if(isset($_POST["mode"]) && $_POST["mode"] != ""){
	switch($_POST["mode"]){
		case "save":
			if($_POST["comment"] != ""){
				save_data();
			}
		break;
		
		case "delete":
			if($_POST["index"] != ""){
				delete_data($_POST["index"]);
			}
		break;
		
	}
  
}

if(isset($_GET["mode"],$_GET["callback"],$_GET["page"]) && $_GET["mode"] == "load"){
	$callback = $_GET["callback"];
	/*$logdata = load_data();
	print $callback . "({\"items\":".json_encode($logdata)."});";*/
	
	$logdata = get_data($_GET["page"],DISPMAX);
	print $callback . "({\"items\":".FastJSON::convert($logdata[0]).",\"pagenum\":".ceil($logdata[1]).",\"current\":".$_GET["page"]."});";
}


/**
 * 削除処理
 * 
 -----------------------------------------------------*/
function delete_data($index)
{
	$logdata = load_data();
	$contents = array();
	
	foreach ($logdata as $line => $data) {
		if($data["id"] != $index){
			$contents[] = $data;
		}
	}
	
	write_data($contents);
	
	//createJSON($contents);
	
	print "削除しました";
}

/**
 *　ローディング
------------------------------------------------------*/
function load_data()
{	
	$contents = array();
	
	$fp = fopen(ABSDIR.LOGFILE, "r");
	flock($fp, LOCK_EX);
	
	while (($data = fgetcsv($fp, 1000, ",")) !== FALSE) {
		$contents[] = array_combine(array("id","date","comment"),$data);
	}
	
  	flock($fp, LOCK_UN);
	fclose($fp);
	
	return $contents;
}

/*
 * ローディングポスト
--------------------------------------------------------*/
function get_data($page = 0, $max)
{

	$logdata = load_data();
	$logcount= count($logdata);
	$max = isset($max)? $max : $logcount;
	$count = count_maxpage($max, $logcount);
	$output = disp_data($logdata,$page, $max, $count);
	$paged = paged($page, $max, $count);
	
	return array($output,$count['max'],$logcount);
}
/**
 * ライティング
------------------------------------------------------*/
function write_data($contents)
{	
	$logcount = count($contents);

	$fp = fopen(ABSDIR.LOGFILE, "w");
	flock($fp, LOCK_EX);
	
	//書き込み
	for($i = 0; $i < SAVEMAX ; $i++){
		if($logcount <= $i) continue;
		$data = array_values($contents[$i]);
		fwrite($fp,$data[0].",".$data[1].",\"".$data[2]."\"\n");
		
	}
	
	flock($fp, LOCK_UN);
	fclose($fp);
	
	return true;
}

/**
 * 保存処理
 -----------------------------------------------------*/
function save_data()
{
	
	$new_line = array("id"=>time(),
					  "date"=>strtotime($_POST["year"]."-".$_POST["month"]."-".$_POST["day"]." ".$_POST["hour"].":".$_POST["min"].":00"),
					  "comment"=>comment_format($_POST["comment"])
					  );
	
	//ログの読み込みと新行の追加
	$contents = load_data();
	$contents[]= $new_line;//NEW LINE
	
	$logcount = count($contents);
	
	for($n = 0; $n < $logcount ;$n++){
		$id[$n] = $contents[$n]["id"];
		$postdate[$n]= $contents[$n]["date"].":00";
	}
	
	array_multisort($postdate,SORT_DESC,$id,SORT_DESC,$contents);//並び替え
	
	write_data($contents);
	
	//print json_encode($new_line); //admin.js用
	
	print FastJSON::convert($new_line);
}

/**
 * コメントの整形
----------------------------------------------------*/
function comment_format($str)
{
	global $arrow_tags;
	$str = str_replace("\0", "", trim($str));
	
	$str = htmlentities(strip_tags($str),ENT_QUOTES,"UTF-8");
	
	$wiki_characters= array('/\|{2}(.+?)\|{2}/i','/\/{2}(.+?)\/{2}/i','/\[{2}(.+?):(.*?)\]{2}/i','/\173([\w]+?):(.+?)\175/i','/\173(#[\d\w]{6}):(.+?)\175/i');
	$wiki_replace = array('<strong>$1</strong>','<em>$1</em>','<a href=\'$2\'>$1</a>','<span style=\'color:$1;\'>$2</span>','<span style=\'color:$1;\'>$2</span>');
	
	$str= preg_replace($wiki_characters,$wiki_replace,$str);
	
	$str = nl2br($str);
	$str = str_replace(array("\r\n", "\n\n","\r", "\n"), "", $str);
	$str = str_replace(array("	",","),array("\t",'&#044;'),$str);

	if (get_magic_quotes_gpc()) {
		$str = stripslashes($str);
	}
	
	return $str;
}


//pagination
function disp_data($logdata,$page=0,$limit,$count){
	
	$start = $page * $count['lng'];
	$end   = ($page * $count['lng']) + $count['lng'];

	for($i=$start;$i<$end;$i++){
		
		if($i >= $count['row']){break;}
		
		$output[] = $logdata[$i];
		
	}
	return $output;
}

/* ページ送り*/
function paged($page=0,$limit,$count)
{
	$paged['current'] = $page;
	$paged['total'] = $count['row'];
	$paged['start'] = ($page*$count['lng'])+1;
	$paged['lng']=$count['lng'];
	
    if($count['max'] > $page){
        $paged["next"] = $page + 1;
    }else{
        $paged["next"] = false;
    }
	
	$paged['max'] = ceil($count['max']);
	
    if($page - 1 >= 0){
        $paged["previous"] = $page - 1;
    }
	
    return $paged; 
}

/* ページ数カウント*/
function count_maxpage($limit, $logcount, $maxpage=5)
{
	
	$count['lng'] = $limit; //１ページあたりの表示数
	$count['row'] = $logcount; //データ数
		
	//全ページ数を求める処理
	$count['max'] = $count['row']/$count['lng'];
	$tmp = (int)$count['max'];
	if($maxpage>$tmp){$count['max']=$tmp+1;}
	$count['max']--;
	
	return $count;
}

//最終更新日取得(use feed.php)
function get_lastpostmodified($case = "rss")
{
	$stmp = filemtime(ABSDIR.LOGFILE);
	
	switch($case){
		case "atom":
			return date3339($stmp);
		break;
		
		case "rss":
			return gmdate('D, d M Y H:i:s',$stmp)." GMT";
		break;
	}
}

//date3399 snippet
//http://www.ibm.com/developerworks/jp/xml/library/x-phpatomfeed/
function date3339($timestamp=0) {
	if (!$timestamp) {
		$timestamp = time();
	}
	
	$date = date('Y-m-d\TH:i:s', $timestamp);

	$matches = array();
	if (preg_match('/^([\-+])(\d{2})(\d{2})$/', date('O', $timestamp), $matches)) {
		$date .= $matches[1].$matches[2].':'.$matches[3];
	} else {
		$date .= 'Z';
	}

	return $date;
}

//ファイルURI(use feed.php)
function self_link() {
	$host = parse_url(SITEURL);
	echo 'http'. ( (isset($_SERVER['https']) && $_SERVER['https'] == 'on') ? 's' : '' ) . '://'.$host['host'].str_replace("&","&amp;",stripslashes($_SERVER['REQUEST_URI']));
}
?>